@@ -1,5 +1,4 @@
-__version__ = "0.1.3"
-
+from .aws_operations import *
 from .eid import *
 from .etl_helpers import *
 from .http_endpoints import *
